/*****************************************************************************
/*
/*            INSTITUTO NACIONAL PARA LA EVALUACIN DE LA EDUCACIN
/*                       DIRECCIN DE PRUEBAS Y MEDICIN
/*                           SUBDIRECCION DE ANLISIS
/*_____________________________________________________________________________
/*
/*            EXAMENES DE LA CALIDAD Y EL LOGRO EDUCATIVOS (Excale)
/*                     SEXTO GRADO DE PRIMARIA (Excale 06)
/*
/*                              **** CONTEXTO ****
/*
/*                     Ciclo escolar evaluado: 2008 - 2009
/*_____________________________________________________________________________
/*
/*
/*       PROGRAMA PARA CONSTRUIR LA BASE DE DATOS DE ALUMNOS DE CONTEXTO
/*                               EN FORMATO SAS
/*_____________________________________________________________________________
/*
/*  El programa convierte al archivo Excale06_2009_Alum_cuest.txt, el cual est en
/*  formato ASCII, en una base de datos en formato SAS. El programa realiza las
/*  siguientes tareas:
/*   - Declara formatos para algunas variables
/*   - Lee las variables del archivo en formato ASCII
/*   - Declara los valores considerados en el anlisis como perdidos (missing values)
/*
/* INSTRUCCIONES
/*  Para construir la base de datos (tabla de datos) es necesario:
/*      1) Crear una carpeta de trabajo y colocar en ella al archivo Excale06_2009_Alum_cuest.txt
/*         as como el archivo Excale06_2009_Alum_cuest.SAS (este archivo) los cules se pueden
/*         descargar del sitio web del INEE (www.inee.edu.mx).
/*      2) Modificar la primera y segunda lnea de los comandos de este archivo
/*         (libname y filename) para actualizar el nombre de la librera y el archivo
/*         de trabajo.
/*      3) Ejecutar el programa del archivo.
/*
/*  Al finalizar, se deber contar con la base de datos (tabla de datos) Excale06_2009_Alum_cuest.sas7bdat
/*
/*  Posteriormente, cuando se desee utilizar nuevamente la base Excale06_2009_Alum_cuest.sas7bdat,
/*  se deber ejecutar primero el procedimiento FORMAT ("proc FORMAT") de este programa para que
/*  SAS cargue los formatos necesarios para abrir la base.
/*
/* CONTACTO:
/*
/*      Para mayor informacin o aclaracin de dudas favor de contactar a la
/*      Subdireccin de Anlisis del Instituto
/*      Correo electrnico: excale.analisis@inee.edu.mx
/*      Tel 5482 0900 Ext. 1082
/*      Domicilio: Jos Ma. Velasco No. 101. 3er piso. Col. San Jos Insurgentes
/*                 Del. Benito Jurez. Mxico. D.F.
/*
/* FECHA DE LIBERACIN: 20 DE ABRIL DE 2012
/*
/*  ****************************************************************************/

LIBNAME  INEE  "C:\***\";
FILENAME alum  "C:\***\Excale06_2009_Alum_cuest.TXT";

PROC FORMAT;
     VALUE id_entF     1         ="Aguascalientes"
                       2         ="Baja California"
                       3         ="Baja California Sur"
                       4         ="Campeche"
                       5         ="Coahuila"
                       6         ="Colima"
                       7         ="Chiapas"
                       8         ="Chihuahua"
                       9         ="Distrito Federal"
                       10        ="Durango"
                       11        ="Guanajuato"
                       12        ="Guerrero"
                       13        ="Hidalgo"
                       14        ="Jalisco"
                       15        ="Mxico"
                       16        ="Michoacn"
                       17        ="Morelos"
                       18        ="Nayarit"
                       19        ="Nuevo Len"
                       20        ="Oaxaca"
                       21        ="Puebla"
                       22        ="Quertaro"
                       23        ="Quintana Roo"
                       24        ="San Luis Potos"
                       25        ="Sinaloa"
                       26        ="Sonora"
                       27        ="Tabasco"
                       28        ="Tamaulipas"
                       29        ="Tlaxcala"
                       30        ="Veracruz"
                       31        ="Yucatn"
                       32        ="Zacatecas";
     VALUE id_modF     1         ="Urbana Pblica"
                       2         ="Rural Pblica"
                       3         ="Educacin Indgena"
                       4         ="Curso Comunitario"
                       5         ="Privada"
                       6         ="General"
                       7         ="Tcnica"
                       8         ="Telesecundaria"
                       9         ="Privada";
     VALUE $modF       "UP"      ="Urbano Pblico"
                       "RP"      ="Rural Pblico"
                       "EI"      ="Educacin Indgena"
                       "CC"      ="Cursos Comunitarios"
                       "UPV"     ="Privados"
                       "GRAL"    ="General"
                       "TEC"     ="Tcnica"
                       "TV"      ="Telesecundaria"
                       "PRIV"    ="Privada";
     VALUE $gmF        "1"       ="Muy alto"
                       "2"       ="Alto"
                       "3"       ="Medio"
                       "4"       ="Bajo"
                       "5"       ="Muy bajo"
                       "9"       ="Perdido"
                       "NA"      ="No aplica";
     VALUE marg_urF    1         ="Alta marginacin"
                       2         ="Baja marginacin"
                       7         ="No aplica";
     VALUE sexoF       1         ="Hombre"
                       2         ="Mujer"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE edadF       99        ="Respuesta omitida";
     VALUE edadcF      1         ="Once aos o menos"
                       2         ="Doce aos"
                       3         ="Trece aos"
                       4         ="Catorce aos o ms"
                       9         ="Respuesta omitida";
     VALUE edadnF      1         ="Edad normativa"
                       2         ="Extra-edad"
                       9         ="Respuesta omitida";
     VALUE edad_acF    10        ="10 aos"
                       11        ="11 aos"
                       12        ="12 aos"
                       13        ="13 aos"
                       14        ="14 aos"
                       15        ="15 aos o ms"
                       98        ="Respuesta mltiple"
                       99        ="Respuesta omitida";
     VALUE mes_nacF    1         ="Enero"
                       2         ="Febrero"
                       3         ="Marzo"
                       4         ="Abril"
                       5         ="Mayo"
                       6         ="Junio"
                       7         ="Julio"
                       8         ="Agosto"
                       9         ="Septiembre"
                       10        ="Octubre"
                       11        ="Noviembre"
                       12        ="Diciembre"
                       98        ="Respuesta mltiple"
                       99        ="Respuesta omitida";
     VALUE docenteF    99999     ="Respuesta omitida";
     VALUE AP1_AP5F    0         ="El espaol"
                       1         ="Una lengua indgena (nhuatl, maya, purpecha, mixteco, otom u otra)"
                       2         ="Un idioma extranjero (francs, ingls, alemn u otro)"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE AP006F      00        ="No tengo mam o tutora"
                       01        ="Ama de casa"
                       02        ="Ocupaciones elementales (albail, pen, campesina, comerciante no establecida,pescadora,minera,empleada domstica, otra)"
                       03        ="Trabajadora manual (obrera, plomera, electricista, carpintera, jardinera, zapatera, etctera)"
                       04        ="Empleada de servicios-asalariada (mesera, polica, soldada, marina, chofer, otra)"
                       05        ="Prestadora de servicios-empleadora o duea (comerciante establecida, restaurantera, encargada de establecimiento, etc.)"
                       06        ="Empleada de oficina (recepcionista, archivista, secretaria, capturista, burcrata, asistente, auxiliar, etctera)"
                       07        ="Tcnica especializada en mecnica, en enfermera, en gastronoma, en computacin, etctera"
                       08        ="Profesionista (mdica, ingeniera, abogada, profesora, dentista, otra profesin)"
                       09        ="Directivo de instituciones pblicas o privadas (empresas, compaas, sociedades, etctera)"
                       98        ="Respuesta mltiple"
                       99        ="Respuesta omitida";
     VALUE AP007F      0         ="No tengo mam o tutora"
                       1         ="No fue a la escuela"
                       2         ="Primaria"
                       3         ="Secundaria"
                       4         ="Bachillerato o preparatoria"
                       5         ="Licenciatura (carrera universitaria)"
                       6         ="Posgrado (maestra o doctorado)"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE AP008F      00        ="No tengo pap o tutor"
                       01        ="No trabaja"
                       02        ="Ocupaciones elementales (albail, pen, campesino, comerciante no establecido,pescador,minero,empleado domstico, otro)"
                       03        ="Trabajador manual (obrero, plomero, electricista, carpintero, jardinero, zapatero, etctera)"
                       04        ="Empleado de servicios-asalariado (mesero, polica, soldado, marino, chofer, otro)"
                       05        ="Prestador de servicios-empleador o dueo (comerciante establecido, restaurantero, encargado de establecimiento, etc.)"
                       06        ="Empleado de oficina (recepcionista, archivista, secretario, capturista, burcrata, asistente, auxiliar, etctera)"
                       07        ="Tcnico especializado en mecnica, en enfermera, en gastronoma, en computacin, etctera"
                       08        ="Profesionista (mdico, ingeniero,abogado, profesor, dentista, otra profesin)"
                       09        ="Directivo de instituciones pblicas o privadas (empresas, compaas, sociedades, etctera)"
                       98        ="Respuesta mltiple"
                       99        ="Respuesta omitida";
     VALUE AP009F      0         ="No tengo pap o tutor"
                       1         ="No fue a la escuela"
                       2         ="Primaria"
                       3         ="Secundaria"
                       4         ="Bachillerato o preparatoria"
                       5         ="Licenciatura (carrera universitaria)"
                       6         ="Posgrado (maestra o doctorado)"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE AP010F      1         ="Primaria"
                       2         ="Secundaria"
                       3         ="Bachillerato o preparatoria"
                       4         ="Carrera tcnica"
                       5         ="Licenciatura (carrera universitaria)"
                       6         ="Posgrado (maestra o doctorado)"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE AP011F      0         ="No s"
                       1         ="Primaria"
                       2         ="Secundaria"
                       3         ="Bachillerato o preparatoria"
                       4         ="Carrera tcnica"
                       5         ="Licenciatura (carrera universitaria)"
                       6         ="Posgrado (maestra o doctorado)"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE AP012F      0         ="Ninguno"
                       1         ="Como 10 libros"
                       2         ="Como 25 libros"
                       3         ="Como 50 libros"
                       4         ="Como 100 libros"
                       5         ="200 libros o ms"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE AP013F      0         ="Con ninguno de los dos"
                       1         ="Con mi pap"
                       2         ="Con mi mam"
                       3         ="Con mi pap y mi mam"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE AP014F      1         ="Nunca o casi nunca"
                       2         ="Varias veces por mes"
                       3         ="Varias veces por semana"
                       4         ="Diariamente"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE AP015F      1         ="Minutos"
                       2         ="Horas"
                       3         ="Das"
                       4         ="Semanas"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE AP16_17F    1         ="Nunca o casi nunca"
                       2         ="Varias veces por mes"
                       3         ="Varias veces por semana"
                       4         ="Diariamente"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE AP18_22F    1         ="Nunca o casi nunca"
                       2         ="Pocas veces"
                       3         ="Frecuentemente"
                       4         ="Muy frecuentemente"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE AP023F      0         ="No la realic"
                       1         ="Menos de 1 hora por da"
                       2         ="De 1 a 2 horas por da"
                       3         ="3  ms horas por da"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE AP024F      0         ="Tierra, tablones de madera, cartn, etctera"
                       1         ="Cemento sin recubrimiento"
                       2         ="Loseta, alfombra, parquet, duela, etctera"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE AP025F      0         ="Ninguno"
                       1         ="1"
                       2         ="2"
                       3         ="3  ms"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE AP26_30F    1         ="S"
                       0         ="No"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE AP031F      0         ="S"
                       1         ="No"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE AP032F      01        ="0 - 1"
                       02        ="2 - 3"
                       03        ="4 - 5"
                       04        ="6 - 7"
                       05        ="8 - 9"
                       06        ="10 a 15"
                       07        ="16 a 25"
                       08        ="26 focos o ms"
                       98        ="Respuesta mltiple"
                       99        ="Respuesta omitida";
     VALUE AP033F      0         ="No sales de vacaciones"
                       1         ="Lugares dentro del estado donde vives"
                       2         ="Lugares o ciudades de otros estados"
                       3         ="Lugares o ciudades de otros pases"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE AP034F      0         ="No tiene servicio mdico"
                       1         ="Seguro Popular, centro de salud, farmacia o dispensario"
                       2         ="IMSS, ISSSTE o instituciones equivalentes"
                       3         ="Servicio privado"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE AP35_36F    1         ="S"
                       0         ="No"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE AP037F      0         ="Ninguno"
                       1         ="1 ao"
                       2         ="2 aos"
                       3         ="3 aos"
                       4         ="4 aos o ms"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE AP038F      1         ="5 aos"
                       2         ="6 aos"
                       3         ="7 aos"
                       4         ="8 aos o ms"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE AP039F      1         ="Menos de 1 ao"
                       2         ="1  2 aos"
                       3         ="3  4 aos"
                       4         ="5 aos o ms"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE AP040F      0         ="Ninguno"
                       1         ="1 ao"
                       2         ="2 aos o ms"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE AP041F      0         ="Ninguno"
                       1         ="Primero"
                       2         ="Segundo"
                       3         ="Tercero"
                       4         ="Cuarto"
                       5         ="Quinto"
                       6         ="Sexto"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE AP042F      0         ="Ninguna"
                       1         ="Entre 1 y 2"
                       2         ="Entre 3 y 5"
                       3         ="Entre 6 y 9"
                       4         ="10 pginas o ms"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE AP043F      0         ="Ninguna"
                       1         ="Pocas"
                       2         ="Muchas"
                       3         ="Todas"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE AP044F      0         ="Ninguno"
                       1         ="1 da"
                       2         ="2  3 das"
                       3         ="4  5 das"
                       4         ="6  7 das "
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE AP045F      0         ="Ninguna"
                       1         ="1 hora o menos"
                       2         ="2 horas"
                       3         ="3 horas"
                       4         ="4 horas o ms"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE AP046F      1         ="S"
                       0         ="No"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE AP047F      0         ="No s"
                       1         ="Poco"
                       2         ="Mucho"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE AP48_50F    1         ="Nunca o casi nunca"
                       2         ="Pocas veces"
                       3         ="Frecuentemente"
                       4         ="Muy frecuentemente"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE AP51_55F    0         ="Nunca"
                       1         ="Casi nunca"
                       2         ="Algunas veces"
                       3         ="Frecuentemente"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE AP056F      0         ="Nunca"
                       1         ="Varias veces por mes"
                       2         ="Varias veces por semana"
                       3         ="Diariamente"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE AP057F      0         ="No lo he hecho"
                       4         ="10 aos o menos"
                       3         ="11 aos"
                       2         ="12 aos"
                       1         ="13 aos o ms"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE AP058F      0         ="Nunca"
                       1         ="Varias veces por mes"
                       2         ="Varias veces por semana"
                       3         ="Diariamente"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE AP059F      0         ="No lo he hecho"
                       4         ="10 aos o menos"
                       3         ="11 aos"
                       2         ="12 aos"
                       1         ="13 aos o ms"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE AP060F      0         ="Nunca"
                       1         ="Varias veces por mes"
                       2         ="Varias veces por semana"
                       3         ="Diariamente"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE AP061F      0         ="No he consumido"
                       4         ="10 aos o menos"
                       3         ="11 aos"
                       2         ="12 aos"
                       1         ="13 aos o ms"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE AP62_68F    1         ="S"
                       0         ="No"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE AP69_76F    1         ="Nunca o casi nunca"
                       2         ="Pocas veces"
                       3         ="Frecuentemente"
                       4         ="Muy frecuentemente"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE AP77_79F    0         ="Nunca"
                       1         ="Casi nunca"
                       2         ="Algunas veces"
                       3         ="Frecuentemente"
                       4         ="Muy frecuentemente"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE AP80_82F    1         ="Nunca o casi nunca"
                       2         ="Pocas veces"
                       3         ="Frecuentemente"
                       4         ="Muy frecuentemente"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE AP83_90F
                       4         ="Nunca o casi nunca"
                       3         ="Pocas veces"
                       2         ="Frecuentemente"
                       1         ="Muy frecuentemente"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE AP91_98F    1         ="Nunca o casi nunca"
                       2         ="Pocas veces"
                       3         ="Frecuentemente"
                       4         ="Muy frecuentemente"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
RUN;



DATA INEE.Excale06_2009_Alum_cuest;
   LENGTH
       NACIONAL           3
       ESCUELA            4
       ID_ENT             3
       NOM_ENT            $19
       ID_MOD             3
       MOD                $4
       GM                 $2
       MARG_URB           3
       ESTRATO            $7
       ENTEST             $6
       ALUMNO             6
       ID_INSTR           $16
       SEXO               3
       EDAD               8
       EDADC              3
       EDADN              3
       EDAD_AC            3
       MES_NAC            3
       W_ALU              8
       DOCENTE            5
       AP001              3
       AP002              3
       AP003              3
       AP004              3
       AP005              3
       AP006              3
       AP007              3
       AP008              3
       AP009              3
       AP010              3
       AP011              3
       AP012              3
       AP013              3
       AP014              3
       AP015              3
       AP016              3
       AP017              3
       AP018              3
       AP019              3
       AP020              3
       AP021              3
       AP022              3
       AP023              3
       AP024              3
       AP025              3
       AP026              3
       AP027              3
       AP028              3
       AP029              3
       AP030              3
       AP031              3
       AP032              3
       AP033              3
       AP034              3
       AP035              3
       AP036              3
       AP037              3
       AP038              3
       AP039              3
       AP040              3
       AP041              3
       AP042              3
       AP043              3
       AP044              3
       AP045              3
       AP046              3
       AP047              3
       AP048              3
       AP049              3
       AP050              3
       AP051              3
       AP052              3
       AP053              3
       AP054              3
       AP055              3
       AP056              3
       AP057              3
       AP058              3
       AP059              3
       AP060              3
       AP061              3
       AP062              3
       AP063              3
       AP064              3
       AP065              3
       AP066              3
       AP067              3
       AP068              3
       AP069              3
       AP070              3
       AP071              3
       AP072              3
       AP073              3
       AP074              3
       AP075              3
       AP076              3
       AP077              3
       AP078              3
       AP079              3
       AP080              3
       AP081              3
       AP082              3
       AP083              3
       AP084              3
       AP085              3
       AP086              3
       AP087              3
       AP088              3
       AP089              3
       AP090              3
       AP091              3
       AP092              3
       AP093              3
       AP094              3
       AP095              3
       AP096              3
       AP097              3
       AP098              3
       WVARSTRR           3
       W_FSTR1            8
       W_FSTR2            8
       W_FSTR3            8
       W_FSTR4            8
       W_FSTR5            8
       W_FSTR6            8
       W_FSTR7            8
       W_FSTR8            8
       W_FSTR9            8
       W_FSTR10           8
       W_FSTR11           8
       W_FSTR12           8
       W_FSTR13           8
       W_FSTR14           8
       W_FSTR15           8
       W_FSTR16           8
       W_FSTR17           8
       W_FSTR18           8
       W_FSTR19           8
       W_FSTR20           8
       W_FSTR21           8
       W_FSTR22           8
       W_FSTR23           8
       W_FSTR24           8
       W_FSTR25           8
       W_FSTR26           8
       W_FSTR27           8
       W_FSTR28           8
       W_FSTR29           8
       W_FSTR30           8
       W_FSTR31           8
       W_FSTR32           8
       W_FSTR33           8
       W_FSTR34           8
       W_FSTR35           8
       W_FSTR36           8
       W_FSTR37           8
       W_FSTR38           8
       W_FSTR39           8
       W_FSTR40           8
       W_FSTR41           8
       W_FSTR42           8
       W_FSTR43           8
       W_FSTR44           8
       W_FSTR45           8
       W_FSTR46           8
       W_FSTR47           8
       W_FSTR48           8
       W_FSTR49           8
       W_FSTR50           8
       W_FSTR51           8
       W_FSTR52           8
       W_FSTR53           8
       W_FSTR54           8
       W_FSTR55           8
       W_FSTR56           8
       W_FSTR57           8
       W_FSTR58           8
       W_FSTR59           8
       W_FSTR60           8
       W_FSTR61           8
       W_FSTR62           8
       W_FSTR63           8
       W_FSTR64           8
       W_FSTR65           8
       W_FSTR66           8
       W_FSTR67           8
       W_FSTR68           8
       W_FSTR69           8
       W_FSTR70           8
       W_FSTR71           8
       W_FSTR72           8
       W_FSTR73           8
       W_FSTR74           8
       W_FSTR75           8
       W_FSTR76           8
       W_FSTR77           8
       W_FSTR78           8
       W_FSTR79           8
       W_FSTR80           8
 ;

INFILE alum MISSOVER LINESIZE = 1086;
   INPUT
       NACIONAL           1 - 1
       ESCUELA            2 - 5
       ID_ENT             6 - 7
       NOM_ENT            8 - 26
       ID_MOD            27 - 27
       MOD               28 - 31
       GM                32 - 33
       MARG_URB          34 - 34
       ESTRATO           35 - 41
       ENTEST            42 - 47
       ALUMNO            48 - 53
       ID_INSTR          54 - 69
       SEXO              70 - 70
       EDAD              71 - 81
       EDADC             82 - 82
       EDADN             83 - 83
       EDAD_AC           84 - 85
       MES_NAC           86 - 87
       W_ALU             88 - 98
       DOCENTE           99 - 103
       AP001            104 - 104
       AP002            105 - 105
       AP003            106 - 106
       AP004            107 - 107
       AP005            108 - 108
       AP006            109 - 110
       AP007            111 - 111
       AP008            112 - 113
       AP009            114 - 114
       AP010            115 - 115
       AP011            116 - 116
       AP012            117 - 117
       AP013            118 - 118
       AP014            119 - 119
       AP015            120 - 120
       AP016            121 - 121
       AP017            122 - 122
       AP018            123 - 123
       AP019            124 - 124
       AP020            125 - 125
       AP021            126 - 126
       AP022            127 - 127
       AP023            128 - 128
       AP024            129 - 129
       AP025            130 - 130
       AP026            131 - 131
       AP027            132 - 132
       AP028            133 - 133
       AP029            134 - 134
       AP030            135 - 135
       AP031            136 - 136
       AP032            137 - 138
       AP033            139 - 139
       AP034            140 - 140
       AP035            141 - 141
       AP036            142 - 142
       AP037            143 - 143
       AP038            144 - 144
       AP039            145 - 145
       AP040            146 - 146
       AP041            147 - 147
       AP042            148 - 148
       AP043            149 - 149
       AP044            150 - 150
       AP045            151 - 151
       AP046            152 - 152
       AP047            153 - 153
       AP048            154 - 154
       AP049            155 - 155
       AP050            156 - 156
       AP051            157 - 157
       AP052            158 - 158
       AP053            159 - 159
       AP054            160 - 160
       AP055            161 - 161
       AP056            162 - 162
       AP057            163 - 163
       AP058            164 - 164
       AP059            165 - 165
       AP060            166 - 166
       AP061            167 - 167
       AP062            168 - 168
       AP063            169 - 169
       AP064            170 - 170
       AP065            171 - 171
       AP066            172 - 172
       AP067            173 - 173
       AP068            174 - 174
       AP069            175 - 175
       AP070            176 - 176
       AP071            177 - 177
       AP072            178 - 178
       AP073            179 - 179
       AP074            180 - 180
       AP075            181 - 181
       AP076            182 - 182
       AP077            183 - 183
       AP078            184 - 184
       AP079            185 - 185
       AP080            186 - 186
       AP081            187 - 187
       AP082            188 - 188
       AP083            189 - 189
       AP084            190 - 190
       AP085            191 - 191
       AP086            192 - 192
       AP087            193 - 193
       AP088            194 - 194
       AP089            195 - 195
       AP090            196 - 196
       AP091            197 - 197
       AP092            198 - 198
       AP093            199 - 199
       AP094            200 - 200
       AP095            201 - 201
       AP096            202 - 202
       AP097            203 - 203
       AP098            204 - 204
       WVARSTRR         205 - 206
       W_FSTR1          207 - 217
       W_FSTR2          218 - 228
       W_FSTR3          229 - 239
       W_FSTR4          240 - 250
       W_FSTR5          251 - 261
       W_FSTR6          262 - 272
       W_FSTR7          273 - 283
       W_FSTR8          284 - 294
       W_FSTR9          295 - 305
       W_FSTR10         306 - 316
       W_FSTR11         317 - 327
       W_FSTR12         328 - 338
       W_FSTR13         339 - 349
       W_FSTR14         350 - 360
       W_FSTR15         361 - 371
       W_FSTR16         372 - 382
       W_FSTR17         383 - 393
       W_FSTR18         394 - 404
       W_FSTR19         405 - 415
       W_FSTR20         416 - 426
       W_FSTR21         427 - 437
       W_FSTR22         438 - 448
       W_FSTR23         449 - 459
       W_FSTR24         460 - 470
       W_FSTR25         471 - 481
       W_FSTR26         482 - 492
       W_FSTR27         493 - 503
       W_FSTR28         504 - 514
       W_FSTR29         515 - 525
       W_FSTR30         526 - 536
       W_FSTR31         537 - 547
       W_FSTR32         548 - 558
       W_FSTR33         559 - 569
       W_FSTR34         570 - 580
       W_FSTR35         581 - 591
       W_FSTR36         592 - 602
       W_FSTR37         603 - 613
       W_FSTR38         614 - 624
       W_FSTR39         625 - 635
       W_FSTR40         636 - 646
       W_FSTR41         647 - 657
       W_FSTR42         658 - 668
       W_FSTR43         669 - 679
       W_FSTR44         680 - 690
       W_FSTR45         691 - 701
       W_FSTR46         702 - 712
       W_FSTR47         713 - 723
       W_FSTR48         724 - 734
       W_FSTR49         735 - 745
       W_FSTR50         746 - 756
       W_FSTR51         757 - 767
       W_FSTR52         768 - 778
       W_FSTR53         779 - 789
       W_FSTR54         790 - 800
       W_FSTR55         801 - 811
       W_FSTR56         812 - 822
       W_FSTR57         823 - 833
       W_FSTR58         834 - 844
       W_FSTR59         845 - 855
       W_FSTR60         856 - 866
       W_FSTR61         867 - 877
       W_FSTR62         878 - 888
       W_FSTR63         889 - 899
       W_FSTR64         900 - 910
       W_FSTR65         911 - 921
       W_FSTR66         922 - 932
       W_FSTR67         933 - 943
       W_FSTR68         944 - 954
       W_FSTR69         955 - 965
       W_FSTR70         966 - 976
       W_FSTR71         977 - 987
       W_FSTR72         988 - 998
       W_FSTR73         999 - 1009
       W_FSTR74        1010 - 1020
       W_FSTR75        1021 - 1031
       W_FSTR76        1032 - 1042
       W_FSTR77        1043 - 1053
       W_FSTR78        1054 - 1064
       W_FSTR79        1065 - 1075
       W_FSTR80        1076 - 1086
;

   LABEL
       NACIONAL    = "Variable auxiliar para obtener promedios nacionales"
       ESCUELA     = "Identificador de la escuela"
       ID_ENT      = "Entidad federativa (identificador numrico)"
       NOM_ENT     = "Entidad federativa"
       ID_MOD      = "Estrato escolar o Modalidad educativa (identificador numrico)"
       MOD         = "Estrato escolar o Modalidad educativa"
       GM          = "Clave de Grado de Marginacin Urbano oficial/Rural (AGEB/localidad)"
       MARG_URB    = "Marginalidad Urbana"
       ESTRATO     = "Estrato de muestreo. Se construy con ENTIDAD, MODALIDAD Y MARGINALIDAD. No es comn a todas las tablas pues en algunos casos se colapsaron registros"
       ENTEST      = "Estratos del diseo muestral con el que se estiman los parmetros y errores estndar (Entidad federativa-Modalidad)"
       ALUMNO      = "Identificador del alumno"
       ID_INSTR    = "Identificador del cuadernillo de examen"
       SEXO        = "Sexo del alumno"
       EDAD        = "Edad del alumno al mes de mayo de 2009, en aos (al momento de la aplicacin)"
       EDADC       = "Edad del alumno al mes de mayo de 2009, codificada (al momento de la aplicacin)"
       EDADN       = "Edad normativa"
       EDAD_AC     = "Edad en aos cumplidos (al momento de la aplicacin)"
       MES_NAC     = "Mes de nacimiento del alumno (al momento de la aplicacin)"
       W_ALU       = "Peso muestral o ponderador del alumno"
       DOCENTE     = "Identificador del docente que imparte clases al alumno"
       AP001       = "Qu lengua aprendiste a hablar primero?"
       AP002       = "Qu lengua hablas en tu casa la mayor parte del tiempo?"
       AP003       = "Qu lengua hablas en tu escuela la mayor parte del tiempo?"
       AP004       = "Qu lengua hablan tus padres o tutores la mayor parte del tiempo?"
       AP005       = "Qu lengua hablan o hablaban tus abuelos la mayor parte del tiempo?"
       AP006       = "En qu trabaja tu mam o tutora? (Si la respuesta no se encuentra en las opciones, por favor elige la que ms se parezca)"
       AP007       = "Cul es el nivel mximo de estudios que termin tu mam o tutora?"
       AP008       = "En qu trabaja tu pap o tutor? (Si la respuesta no se encuentra en las opciones, por favor elige la que ms se parezca)"
       AP009       = "Cul es el nivel mximo de estudios que termin tu pap o tutor?"
       AP010       = "Hasta qu nivel educativo te gustara estudiar?"
       AP011       = "Hasta qu nivel educativo les gustara a tus padres o tutores que estudiaras?"
       AP012       = "Aproximadamente, cuntos libros hay en tu casa? (No incluyas revistas, ni peridicos, ni tus libros escolares)"
       AP013       = "Con cul de tus padres vives?"
       AP014       = "Qu tan seguido tienes discusiones o conflictos con alguno de tus padres o tutores?"
       AP015       = "Cuando tienes discusiones o conflictos con alguno de tus padres o tutores, cunto tiempo permanecen enojados?"
       AP016       = "Con qu frecuencia tienen discusiones o conflictos las personas que viven en tu casa?"
       AP017       = "Las personas que viven en tu casa se pelean a golpes?"
       AP018       = "Tus padres o tutores estn al pendiente de tus calificaciones?"
       AP019       = "Tus padres o tutores estn al pendiente de los materiales que necesitas para la escuela?"
       AP020       = "En tu casa, tus padres o tutores te ayudan a estudiar o a hacer las tareas cuando lo necesitas?"
       AP021       = "Con qu frecuencia hablas de lo que has aprendido en la escuela con alguna persona de tu familia?"
       AP022       = "Adems de tus padres o tutores, alguna persona de tu familia te ayuda a hacer la tarea cuando lo necesitas?"
       AP023       = "Durante la semana pasada, cunto tiempo ayudaste a tu familia a realizar alguna actividad sin pago alguno? (Labores domsticas, atender un negocio familiar, labores del campo, etctera)"
       AP024       = "De qu material es la mayor parte del piso que est dentro de tu casa?"
       AP025       = "Cuntos cuartos de bao hay en la casa donde vives?"
       AP026       = "En la casa donde vives hay lnea telefnica?"
       AP027       = "En la casa donde vives cuentan con conexin a Internet?"
       AP028       = "En la casa donde vives hay un automvil?"
       AP029       = "En la casa donde vives hay una computadora?"
       AP030       = "En la casa donde vives hay una mquina lavatrastos o lavavajillas?"
       AP031       = "En la casa donde vives duermen tres personas o ms en un solo cuarto?"
       AP032       = "Cuntos focos hay en la casa donde vives?"
       AP033       = "Cuando sales de vacaciones con tu familia, qu lugares frecuentas usualmente?"
       AP034       = "A qu tipo de servicios mdicos acude tu familia?"
       AP035       = "Has recibido o recibes beca del programa Oportunidades?"
       AP036       = "Realizas alguna actividad fuera de casa por la cual te pagan?"
       AP037       = "Cuntos aos fuiste a la escuela antes de entrar a la primaria?"
       AP038       = "A qu edad entraste a la primaria?"
       AP039       = "Cunto tiempo llevas estudiando en esta escuela?"
       AP040       = "Cuntos aos has repetido en la primaria?"
       AP041       = "Qu ao escolar repetiste en la primaria? (Si repetiste ms de uno, seala el ltimo ao repetido)"
       AP042       = "Cuntas pginas lees al da fuera de la escuela para realizar tus tareas?"
       AP043       = "Cuntas tareas de las que te dejaron hiciste el bimestre pasado?"
       AP044       = "Aproximadamente, cuntos das a la semana haces tareas o estudias?"
       AP045       = "En general, cuntas horas al da dedicas a estudiar o hacer tareas fuera de la escuela?"
       AP046       = "Puedes comprender un texto escrito en ingls?"
       AP047       = "Sabes usar una computadora? (Power Point, Excel, Word, Internet, etctera)"
       AP048       = "Lo que aprendes en la escuela te ayuda en tu vida diaria?"
       AP049       = "Cuando no entiendes algo en clase, buscas informacin en otros lugares? (Libros, Internet, revistas, etctera)"
       AP050       = "Cuando te interesa algo que aprendiste en clase, buscas ms informacin en otros lugares? (Libros, Internet, revistas, etctera)"
       AP051       = "En este ao escolar te han llamado la atencin (castigado, reportado, suspendido, etctera) por mala conducta en la escuela?"
       AP052       = "En este ao escolar te has peleado a golpes dentro o fuera de la escuela?"
       AP053       = "En este ao escolar has participado en actividades que daaron las instalaciones, el mobiliario o equipos de la escuela? (Pintas, graffiti, descomponer chapas de puertas, etctera)"
       AP054       = "En este ao escolar has robado algn objeto o dinero dentro de la escuela?"
       AP055       = "En este ao escolar has participado en algn grupo de estudiantes que haya intimidado o amenazado a otros alumnos de la escuela?"
       AP056       = "Consumes alguna bebida que contenga alcohol? (Cerveza, vino, ron, tequila, etctera)"
       AP057       = "Desde qu edad la consumes?"
       AP058       = "Fumas cigarros de tabaco?"
       AP059       = "Desde qu edad los fumas?"
       AP060       = "Consumes algn tipo de droga? (Cocana, mariguana, inhalantes, solventes, etctera)"
       AP061       = "Desde qu edad la consumes?"
       AP062       = "Es posible obtener dentro de tu escuela alguna de las siguientes sustancias: Bebidas alcohlicas"
       AP063       = "Es posible obtener dentro de tu escuela alguna de las siguientes sustancias: Cigarros de tabaco"
       AP064       = "Es posible obtener dentro de tu escuela alguna de las siguientes sustancias: Mariguana"
       AP065       = "Es posible obtener dentro de tu escuela alguna de las siguientes sustancias: Alguna otra droga (cocana, solventes, tachas, etctera)"
       AP066       = "Durante el ao escolar, lleg a ser de tu conocimiento que un alumno o un grupo de alumnos: Consumiera bebidas alcohlicas y/o tabaco dentro de la escuela"
       AP067       = "Durante el ao escolar, lleg a ser de tu conocimiento que un alumno o un grupo de alumnos: Consumiera drogas dentro de la escuela"
       AP068       = "Durante el ao escolar, lleg a ser de tu conocimiento que un alumno o un grupo de alumnos: Vendiera, regalara o distribuyera drogas (no consideres alcohol ni tabaco) dentro de la escuela"
       AP069       = "En este ao escolar, algn estudiante o un grupo de estudiantes ha llevado a la escuela algn arma (pistola, navaja, etctera)?"
       AP070       = "En este ao escolar, han ocurrido peleas a golpes entre los estudiantes?"
       AP071       = "En este ao escolar, algn estudiante o un grupo de estudiantes ha daado las instalaciones, el mobiliario o el equipo de la escuela? (Pintas, graffiti, descomponer chapas de puertas, etctera)"
       AP072       = "En este ao escolar, algn estudiante o grupo de estudiantes ha robado dinero o pertenencias dentro de la escuela?"
       AP073       = "En este ao escolar, algn estudiante o grupo de estudiantes te ha amenazado?"
       AP074       = "En este ao escolar, algn estudiante o grupo de estudiantes te ha agredido fsicamente?"
       AP075       = "En este ao escolar, algn estudiante o grupo de estudiantes se ha burlado de ti o te ha insultado?"
       AP076       = "En este ao escolar, algn estudiante o grupo de estudiantes te ha empujado, te ha escupido, o te ha hecho tropezar?"
       AP077       = "En este ao escolar, tus compaeros te han rechazado para participar en algunas actividades? (Por ejemplo, trabajo en equipo, juegos, deportes, etctera)"
       AP078       = "En este ao escolar, tus compaeros se han burlado de ti por la ropa que usas? (Por ejemplo, si tu uniforme escolar no es nuevo, la marca de la ropa, etctera)"
       AP079       = "En este ao escolar, tus compaeros se han burlado de ti por tu apariencia fsica? (Por ejemplo, el color de tu piel, por problemas de sobrepeso, etctera)"
       AP080       = "Tu maestra(o) se preocupa por lo que te pasa?"
       AP081       = "Confas en tu maestra(o)?"
       AP082       = "Tu maestra(o) te comprende?"
       AP083       = "Qu tan seguido falta tu maestra(o) a clases?"
       AP084       = "Qu tan seguido llega tarde tu maestra(o)?"
       AP085       = "Tu maestra(o) deja solo a tu grupo en horas de clases?"
       AP086       = "Tu maestra(o) platica con otros adultos en horas de clases?"
       AP087       = "Otras personas (director, maestros, compaeros de otros grupos) interrumpen las clases de tu grupo?"
       AP088       = "Tu maestro hace otras cosas en lugar de atender al grupo? (Por ejemplo, hablar por telfono, leer el peridico, etctera)"
       AP089       = "Pasa mucho tiempo entre que terminas un trabajo y empiezas otro en clase?"
       AP090       = "Tu maestra(o) interrumpe sus clases por razones de indisciplina?"
       AP091       = "Tu maestra(o) te explica cmo corregir tus errores?"
       AP092       = "Las tareas, trabajos o ejercicios que dejan tus maestros, se corrigen en clase?"
       AP093       = "Entiendes las explicaciones de tu maestra(o)?"
       AP094       = "Adems del pizarrn, libros y cuadernos, tu maestra(o) utiliza otros materiales para ayudarles a aprender mejor?"
       AP095       = "Tu maestra(o) les deja realizar investigaciones?"
       AP096       = "Tu maestra(o) te permite expresar tus opiniones y dudas?"
       AP097       = "Tu maestra(o) hace que participen en clase?"
       AP098       = "Tu maestra(o) te hace sentir que eres capaz de aprender?"
       WVARSTRR    = "Identificador del pseudoestrato (1 a 80) definido para el clculo de errores estndar con el mtodo de remuestreo BRR"
       W_FSTR1     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR2     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR3     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR4     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR5     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR6     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR7     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR8     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR9     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR10    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR11    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR12    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR13    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR14    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR15    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR16    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR17    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR18    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR19    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR20    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR21    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR22    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR23    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR24    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR25    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR26    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR27    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR28    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR29    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR30    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR31    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR32    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR33    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR34    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR35    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR36    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR37    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR38    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR39    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR40    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR41    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR42    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR43    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR44    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR45    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR46    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR47    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR48    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR49    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR50    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR51    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR52    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR53    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR54    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR55    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR56    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR57    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR58    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR59    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR60    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR61    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR62    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR63    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR64    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR65    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR66    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR67    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR68    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR69    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR70    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR71    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR72    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR73    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR74    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR75    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR76    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR77    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR78    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR79    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR80    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
;

   FORMAT
       NACIONAL           1.
       ESCUELA            4.
       ID_ENT             id_entF.
       NOM_ENT            $char19.
       ID_MOD             id_modF.
       MOD                $modF.
       GM                 $gmF.
       MARG_URB           marg_urF.
       ESTRATO            $char7.
       ENTEST             $char6.
       ALUMNO             5.
       ID_INSTR           $char16.
       SEXO               sexoF.
       EDAD               edadF.
       EDADC              edadcF.
       EDADN              edadnF.
       EDAD_AC            edad_acF.
       MES_NAC            mes_nacF.
       DOCENTE            docenteF.
       AP001              AP1_AP5F.
       AP002              AP1_AP5F.
       AP003              AP1_AP5F.
       AP004              AP1_AP5F.
       AP005              AP1_AP5F.
       AP006              AP006F.
       AP007              AP007F.
       AP008              AP008F.
       AP009              AP009F.
       AP010              AP010F.
       AP011              AP011F.
       AP012              AP012F.
       AP013              AP013F.
       AP014              AP014F.
       AP015              AP015F.
       AP016              AP16_17F.
       AP017              AP16_17F.
       AP018              AP18_22F.
       AP019              AP18_22F.
       AP020              AP18_22F.
       AP021              AP18_22F.
       AP022              AP18_22F.
       AP023              AP023F.
       AP024              AP024F.
       AP025              AP025F.
       AP026              AP26_30F.
       AP027              AP26_30F.
       AP028              AP26_30F.
       AP029              AP26_30F.
       AP030              AP26_30F.
       AP031              AP031F.
       AP032              AP032F.
       AP033              AP033F.
       AP034              AP034F.
       AP035              AP35_36F.
       AP036              AP35_36F.
       AP037              AP037F.
       AP038              AP038F.
       AP039              AP039F.
       AP040              AP040F.
       AP041              AP041F.
       AP042              AP042F.
       AP043              AP043F.
       AP044              AP044F.
       AP045              AP045F.
       AP046              AP046F.
       AP047              AP047F.
       AP048              AP48_50F.
       AP049              AP48_50F.
       AP050              AP48_50F.
       AP051              AP51_55F.
       AP052              AP51_55F.
       AP053              AP51_55F.
       AP054              AP51_55F.
       AP055              AP51_55F.
       AP056              AP056F.
       AP057              AP057F.
       AP058              AP058F.
       AP059              AP059F.
       AP060              AP060F.
       AP061              AP061F.
       AP062              AP62_68F.
       AP063              AP62_68F.
       AP064              AP62_68F.
       AP065              AP62_68F.
       AP066              AP62_68F.
       AP067              AP62_68F.
       AP068              AP62_68F.
       AP069              AP69_76F.
       AP070              AP69_76F.
       AP071              AP69_76F.
       AP072              AP69_76F.
       AP073              AP69_76F.
       AP074              AP69_76F.
       AP075              AP69_76F.
       AP076              AP69_76F.
       AP077              AP77_79F.
       AP078              AP77_79F.
       AP079              AP77_79F.
       AP080              AP80_82F.
       AP081              AP80_82F.
       AP082              AP80_82F.
       AP083              AP83_90F.
       AP084              AP83_90F.
       AP085              AP83_90F.
       AP086              AP83_90F.
       AP087              AP83_90F.
       AP088              AP83_90F.
       AP089              AP83_90F.
       AP090              AP83_90F.
       AP091              AP91_98F.
       AP092              AP91_98F.
       AP093              AP91_98F.
       AP094              AP91_98F.
       AP095              AP91_98F.
       AP096              AP91_98F.
       AP097              AP91_98F.
       AP098              AP91_98F.
       WVARSTRR           2.
   ;

/**************************************************************************
/*  Definicin de valores perdidos
/*   .N o N = No Administrado o no alcanzado.
/*   .M o M = Respuesta Mltiple.
/*   .S o S = Respuesta omitida (No contestado).
/*************************************************************************/
   IF  sexo = 8 THEN  sexo = .M;
   IF  edad_ac = 98 THEN  edad_ac = .M;
   IF  mes_nac = 98 THEN  mes_nac = .M;
   IF  GM = "9"  THEN  GM = .S;
   IF  GM = "NA"  THEN  GM = .S;
   IF  marg_urb = 7 THEN  marg_urb = .S;

   ARRAY perdidos1(3)  sexo edadc edadn;
   DO  i=1 TO 3;
         IF perdidos1{i}=9 THEN  perdidos1{i}= .S;
   END;

   ARRAY perdidos2(3)  edad edad_ac mes_nac;
   DO  i=1 TO 3;
         IF perdidos2{i}=99 THEN  perdidos2{i}= .S;
   END;

   IF  docente = 99999 THEN  docente = .S;

   ARRAY perdidos3(95)
                  AP001 AP002 AP003 AP004 AP005 AP007 AP009 AP010 AP011 AP012
                  AP013 AP014 AP015 AP016 AP017 AP018 AP019 AP020 AP021 AP022
                  AP023 AP024 AP025 AP026 AP027 AP028 AP029 AP030 AP031 AP033
                  AP034 AP035 AP036 AP037 AP038 AP039 AP040 AP041 AP042 AP043
                  AP044 AP045 AP046 AP047 AP048 AP049 AP050 AP051 AP052 AP053
                  AP054 AP055 AP056 AP057 AP058 AP059 AP060 AP061 AP062 AP063
                  AP064 AP065 AP066 AP067 AP068 AP069 AP070 AP071 AP072 AP073
                  AP074 AP075 AP076 AP077 AP078 AP079 AP080 AP081 AP082 AP083
                  AP084 AP085 AP086 AP087 AP088 AP089 AP090 AP091 AP092 AP093
                  AP094 AP095 AP096 AP097 AP098;
   DO  i=1 TO 95;
          IF perdidos3{i} = 8   THEN  perdidos3{i} = .M;
          IF perdidos3{i} = 9   THEN  perdidos3{i} = .S;
   END;



   ARRAY perdidos4(3)
                  AP006 AP008 AP032;
   DO  i=1 TO 3;
          IF perdidos4{i} = 88   THEN  perdidos4{i} = .M;
          IF perdidos4{i} = 99   THEN  perdidos4{i} = .S;
   END;


   drop i;
RUN;
